Roadmap
=======

We are planning on adding the following capabilities / improvements in future releases of stor:

* Testing against Rackspace Cloudfiles
* Support more complicated globbing
* Support region affinity with swift authentication
* GCS and Microsoft Azure support
